@@ -27,7 +27,7 @@ def dingding(access_token, content):
     return "fail: %s" % data.text
 
 
-def falcon(metric, step, value, ctype, tag):
+def falcon(metric, step=60, value, ctype, tag):
     '''
     推送方式：falcon
     '''
